@@ -65,7 +65,7 @@ from griffe.docstrings.dataclasses import (
     DocstringWarn,
     DocstringYield,
 )
-from griffe.docstrings.utils import warning
+from griffe.docstrings.utils import parse_annotation, warning
 from griffe.expressions import Expression, Name
 
 if TYPE_CHECKING:
@@ -102,22 +102,22 @@ def _read_block_items(docstring: Docstring, offset: int) -> tuple[list[list[str]
     if offset >= len(lines):
         return [], offset
 
-    index = offset
+    new_offset = offset
     items: list[list[str]] = []
 
     # skip first empty lines
-    while _is_empty_line(lines[index]):
-        index += 1
+    while _is_empty_line(lines[new_offset]):
+        new_offset += 1
 
     previous_was_empty = False
 
     # start processing first item
-    current_item = [lines[index]]
-    index += 1
+    current_item = [lines[new_offset]]
+    new_offset += 1
 
     # loop on next lines
-    while index < len(lines):
-        line = lines[index]
+    while new_offset < len(lines):
+        line = lines[new_offset]
 
         if line.startswith(4 * " "):
             # continuation line
@@ -130,8 +130,8 @@ def _read_block_items(docstring: Docstring, offset: int) -> tuple[list[list[str]
             current_item.append(line[cont_indent:])
             _warn(
                 docstring,
-                index,
-                f"Confusing indentation for continuation line {index+1} in docstring, "
+                new_offset,
+                f"Confusing indentation for continuation line {new_offset+1} in docstring, "
                 f"should be 4 spaces, not {cont_indent}",
             )
             previous_was_empty = False
@@ -149,38 +149,44 @@ def _read_block_items(docstring: Docstring, offset: int) -> tuple[list[list[str]
             current_item = [line]
             previous_was_empty = False
 
-        index += 1
+        new_offset += 1
 
     if current_item:
         items.append(current_item)
 
-    return items, index - 1
+    return items, new_offset - 1
 
 
-def _read_block(docstring: Docstring, offset: int) -> tuple[str, int]:
+def _read_block(docstring: Docstring, offset: int) -> tuple[str, int]:  # noqa: WPS231
     lines = docstring.lines
     if offset >= len(lines):
         return "", offset
 
-    index = offset
+    new_offset = offset
     block: list[str] = []
 
     # skip first empty lines
-    while _is_empty_line(lines[index]):
-        index += 1
+    while _is_empty_line(lines[new_offset]):
+        new_offset += 1
+    while new_offset < len(lines):
+        is_empty = _is_empty_line(lines[new_offset])
+        if is_empty and _is_dash_line(lines[new_offset + 1]):
+            break  # Break if a new unnamed section is reached.
 
-    while index < len(lines) and not (_is_empty_line(lines[index]) and _is_dash_line(lines[index + 1])):
-        block.append(lines[index])
-        index += 1
+        if is_empty and new_offset < len(lines) + 1 and _is_dash_line(lines[new_offset + 2]):
+            break  # Break if a new named section is reached.
 
-    return "\n".join(block).rstrip("\n"), index - 1
+        block.append(lines[new_offset])
+        new_offset += 1
+
+    return "\n".join(block).rstrip("\n"), new_offset - 1
 
 
 _RE_OB: str = r"\{"  # opening bracket
 _RE_CB: str = r"\}"  # closing bracket
 _RE_NAME: str = r"\*{0,2}[_a-z][_a-z0-9]*"
-_RE_NATURAL_TYPE: str = r"[_a-z0-9 ().'\"-]+"
-_RE_RETURNS: Pattern = re.compile(rf"^(?:(?P<name>{_RE_NAME}) : )?(?P<type>{_RE_NATURAL_TYPE})", re.IGNORECASE)
+_RE_TYPE: str = r"[_a-z0-9 \[\]|().,'\"-]*"
+_RE_RETURNS: Pattern = re.compile(rf"^(?:(?P<name>{_RE_NAME})\s*:\s*)?(?P<type>{_RE_TYPE})", re.IGNORECASE)
 _RE_YIELDS: Pattern = _RE_RETURNS
 _RE_RECEIVES: Pattern = _RE_YIELDS
 _RE_PARAMETER: Pattern = re.compile(
@@ -191,7 +197,7 @@ _RE_PARAMETER: Pattern = re.compile(
         (?:
             (?:{_RE_OB}(?P<choices>.+){_RE_CB})|
             (?:
-                (?P<type>{_RE_NATURAL_TYPE})
+                (?P<type>{_RE_TYPE})
                 (?:,\soptional)?
                 (?:
                     ,\sdefault\s*[:=]\s*
@@ -207,21 +213,26 @@ _RE_DOCTEST_BLANKLINE: Pattern = re.compile(r"^\s*<BLANKLINE>\s*$")
 _RE_DOCTEST_FLAGS: Pattern = re.compile(r"(\s*#\s*doctest:.+)$")
 
 
-def _read_parameters(docstring: Docstring, offset: int) -> tuple[list[DocstringParameter], int]:  # noqa: WPS231
+def _read_parameters(  # noqa: WPS231
+    docstring: Docstring,
+    offset: int,
+    warn_unknown_params: bool = True,
+) -> tuple[list[DocstringParameter], int]:
     parameters = []
     annotation: str | Name | Expression | None
 
-    items, index = _read_block_items(docstring, offset)
+    items, new_offset = _read_block_items(docstring, offset)
 
     for item in items:
 
         match = _RE_PARAMETER.match(item[0])
         if not match:
-            _warn(docstring, index, f"Could not parse line '{item[0]}'")
+            _warn(docstring, new_offset, f"Could not parse line '{item[0]}'")
             continue
 
         names = match.group("names").split(", ")
         annotation = match.group("type")
+        annotation = annotation or None
         choices = match.group("choices")
         if choices:
             choices = choices.split(", ", 1)
@@ -240,7 +251,9 @@ def _read_parameters(docstring: Docstring, offset: int) -> tuple[list[DocstringP
                     annotation = docstring.parent.parameters[name].annotation  # type: ignore[union-attr]
                     break
             else:
-                _warn(docstring, index, f"No types or annotations for parameters {names}")
+                _warn(docstring, new_offset, f"No types or annotations for parameters {names}")
+        else:
+            annotation = parse_annotation(annotation, docstring)  # type: ignore[arg-type]
 
         if default is None:
             for name in names:  # noqa: WPS440
@@ -248,10 +261,22 @@ def _read_parameters(docstring: Docstring, offset: int) -> tuple[list[DocstringP
                     default = docstring.parent.parameters[name].default  # type: ignore[union-attr]
                     break
 
+        if warn_unknown_params:
+            with suppress(AttributeError):  # for parameters sections in objects without parameters
+                params = docstring.parent.parameters  # type: ignore[union-attr]
+                for name in names:  # noqa: WPS440
+                    if name not in params:
+                        message = f"Parameter '{name}' does not appear in the function signature"
+                        for starred_name in (f"*{name}", f"**{name}"):
+                            if starred_name in params:
+                                message += f". Did you mean '{starred_name}'?"
+                                break
+                        _warn(docstring, new_offset, message)
+
         for name in names:  # noqa: WPS440
             parameters.append(DocstringParameter(name, value=default, annotation=annotation, description=description))
 
-    return parameters, index
+    return parameters, new_offset
 
 
 def _read_parameters_section(
@@ -259,13 +284,13 @@ def _read_parameters_section(
     offset: int,
     **options: Any,
 ) -> tuple[DocstringSectionParameters | None, int]:
-    parameters, index = _read_parameters(docstring, offset)
+    parameters, new_offset = _read_parameters(docstring, offset)
 
     if parameters:
-        return DocstringSectionParameters(parameters), index
+        return DocstringSectionParameters(parameters), new_offset
 
-    _warn(docstring, index, f"Empty parameters section at line {offset}")
-    return None, index
+    _warn(docstring, new_offset, f"Empty parameters section at line {offset}")
+    return None, new_offset
 
 
 def _read_other_parameters_section(
@@ -273,13 +298,13 @@ def _read_other_parameters_section(
     offset: int,
     **options: Any,
 ) -> tuple[DocstringSectionOtherParameters | None, int]:
-    parameters, index = _read_parameters(docstring, offset)
+    parameters, new_offset = _read_parameters(docstring, offset, warn_unknown_params=False)
 
     if parameters:
-        return DocstringSectionOtherParameters(parameters), index
+        return DocstringSectionOtherParameters(parameters), new_offset
 
-    _warn(docstring, index, f"Empty other parameters section at line {offset}")
-    return None, index
+    _warn(docstring, new_offset, f"Empty other parameters section at line {offset}")
+    return None, new_offset
 
 
 def _read_deprecated_section(
@@ -290,22 +315,22 @@ def _read_deprecated_section(
     # deprecated
     # SINCE_VERSION
     #     TEXT?
-    items, index = _read_block_items(docstring, offset)
+    items, new_offset = _read_block_items(docstring, offset)
 
     if not items:
-        _warn(docstring, index, f"Empty deprecated section at line {offset}")
-        return None, index
+        _warn(docstring, new_offset, f"Empty deprecated section at line {offset}")
+        return None, new_offset
 
     if len(items) > 1:
-        _warn(docstring, index, f"Too many deprecated items at {offset}")
+        _warn(docstring, new_offset, f"Too many deprecated items at {offset}")
 
     item = items[0]
     version = item[0]
     text = dedent("\n".join(item[1:]))
-    return DocstringSectionDeprecated(version=version, text=text), index
+    return DocstringSectionDeprecated(version=version, text=text), new_offset
 
 
-def _read_returns_section(
+def _read_returns_section(  # noqa: WPS231
     docstring: Docstring,
     offset: int,
     **options: Any,
@@ -313,26 +338,49 @@ def _read_returns_section(
     # returns
     # (NAME : )?TYPE
     #     TEXT?
-    items, index = _read_block_items(docstring, offset)
+    items, new_offset = _read_block_items(docstring, offset)
 
     if not items:
-        _warn(docstring, index, f"Empty returns section at line {offset}")
-        return None, index
+        _warn(docstring, new_offset, f"Empty returns section at line {offset}")
+        return None, new_offset
 
     returns = []
-    for item in items:
+    for index, item in enumerate(items):
         match = _RE_RETURNS.match(item[0])
         if not match:
-            _warn(docstring, index, f"Could not parse line '{item[0]}'")
+            _warn(docstring, new_offset, f"Could not parse line '{item[0]}'")
             continue
 
         name, annotation = match.groups()
+        annotation = annotation or None
         text = dedent("\n".join(item[1:]))
+        if annotation is None:
+            # try to retrieve the annotation from the docstring parent
+            with suppress(AttributeError, KeyError, ValueError):
+                annotation = docstring.parent.returns  # type: ignore[union-attr]
+                if len(items) > 1:
+                    if annotation.is_tuple:
+                        annotation = annotation.tuple_item(index)
+                    else:
+                        if annotation.is_iterator:
+                            return_item = annotation.iterator_item()
+                        elif annotation.is_generator:
+                            _, _, return_item = annotation.generator_items()
+                        else:
+                            raise ValueError
+                        if isinstance(return_item, Name):
+                            annotation = return_item
+                        elif return_item.is_tuple:
+                            annotation = return_item.tuple_item(index)
+                        else:
+                            annotation = return_item
+        else:
+            annotation = parse_annotation(annotation, docstring)  # type: ignore[arg-type]
         returns.append(DocstringReturn(name=name or "", annotation=annotation, description=text))
-    return DocstringSectionReturns(returns), index
+    return DocstringSectionReturns(returns), new_offset
 
 
-def _read_yields_section(
+def _read_yields_section(  # noqa: WPS231
     docstring: Docstring,
     offset: int,
     **options: Any,
@@ -340,26 +388,46 @@ def _read_yields_section(
     # yields
     # (NAME : )?TYPE
     #     TEXT?
-    items, index = _read_block_items(docstring, offset)
+    items, new_offset = _read_block_items(docstring, offset)
 
     if not items:
-        _warn(docstring, index, f"Empty yields section at line {offset}")
-        return None, index
+        _warn(docstring, new_offset, f"Empty yields section at line {offset}")
+        return None, new_offset
 
     yields = []
-    for item in items:
+    for index, item in enumerate(items):
         match = _RE_YIELDS.match(item[0])
         if not match:
-            _warn(docstring, index, f"Could not parse line '{item[0]}'")
+            _warn(docstring, new_offset, f"Could not parse line '{item[0]}'")
             continue
 
         name, annotation = match.groups()
+        annotation = annotation or None
         text = dedent("\n".join(item[1:]))
+        if annotation is None:
+            # try to retrieve the annotation from the docstring parent
+            with suppress(AttributeError, KeyError, ValueError):
+                annotation = docstring.parent.returns  # type: ignore[union-attr]
+                if len(items) > 1:
+                    if annotation.is_iterator:
+                        yield_item = annotation.iterator_item()
+                    elif annotation.is_generator:
+                        yield_item, _, _ = annotation.generator_items()
+                    else:
+                        raise ValueError
+                    if isinstance(yield_item, Name):
+                        annotation = yield_item
+                    elif yield_item.is_tuple:
+                        annotation = yield_item.tuple_item(index)
+                    else:
+                        annotation = yield_item
+        else:
+            annotation = parse_annotation(annotation, docstring)  # type: ignore[arg-type]
         yields.append(DocstringYield(name=name or "", annotation=annotation, description=text))
-    return DocstringSectionYields(yields), index
+    return DocstringSectionYields(yields), new_offset
 
 
-def _read_receives_section(
+def _read_receives_section(  # noqa: WPS231
     docstring: Docstring,
     offset: int,
     **options: Any,
@@ -367,23 +435,38 @@ def _read_receives_section(
     # receives
     # (NAME : )?TYPE
     #     TEXT?
-    items, index = _read_block_items(docstring, offset)
+    items, new_offset = _read_block_items(docstring, offset)
 
     if not items:
-        _warn(docstring, index, f"Empty receives section at line {offset}")
-        return None, index
+        _warn(docstring, new_offset, f"Empty receives section at line {offset}")
+        return None, new_offset
 
     receives = []
-    for item in items:
+    for index, item in enumerate(items):
         match = _RE_RECEIVES.match(item[0])
         if not match:
-            _warn(docstring, index, f"Could not parse line '{item[0]}'")
+            _warn(docstring, new_offset, f"Could not parse line '{item[0]}'")
             continue
 
         name, annotation = match.groups()
+        annotation = annotation or None
         text = dedent("\n".join(item[1:]))
+        if annotation is None:
+            # try to retrieve the annotation from the docstring parent
+            with suppress(AttributeError, KeyError):
+                annotation = docstring.parent.returns  # type: ignore[union-attr]
+                if len(items) > 1 and annotation.is_generator:
+                    _, receives_item, _ = annotation.generator_items()
+                    if isinstance(receives_item, Name):
+                        annotation = receives_item
+                    elif receives_item.is_tuple:
+                        annotation = receives_item.tuple_item(index)
+                    else:
+                        annotation = receives_item
+        else:
+            annotation = parse_annotation(annotation, docstring)  # type: ignore[arg-type]
         receives.append(DocstringReceive(name=name or "", annotation=annotation, description=text))
-    return DocstringSectionReceives(receives), index
+    return DocstringSectionReceives(receives), new_offset
 
 
 def _read_raises_section(
@@ -394,18 +477,18 @@ def _read_raises_section(
     # raises
     # EXCEPTION
     #     TEXT?
-    items, index = _read_block_items(docstring, offset)
+    items, new_offset = _read_block_items(docstring, offset)
 
     if not items:
-        _warn(docstring, index, f"Empty raises section at line {offset}")
-        return None, index
+        _warn(docstring, new_offset, f"Empty raises section at line {offset}")
+        return None, new_offset
 
     raises = []
     for item in items:
-        annotation = item[0]
+        annotation = parse_annotation(item[0], docstring)
         text = dedent("\n".join(item[1:]))
         raises.append(DocstringRaise(annotation=annotation, description=text))
-    return DocstringSectionRaises(raises), index
+    return DocstringSectionRaises(raises), new_offset
 
 
 def _read_warns_section(
@@ -416,18 +499,18 @@ def _read_warns_section(
     # warns
     # WARNING
     #     TEXT?
-    items, index = _read_block_items(docstring, offset)
+    items, new_offset = _read_block_items(docstring, offset)
 
     if not items:
-        _warn(docstring, index, f"Empty warns section at line {offset}")
-        return None, index
+        _warn(docstring, new_offset, f"Empty warns section at line {offset}")
+        return None, new_offset
 
     warns = []
     for item in items:
-        annotation = item[0]
+        annotation = parse_annotation(item[0], docstring)
         text = dedent("\n".join(item[1:]))
         warns.append(DocstringWarn(annotation=annotation, description=text))
-    return DocstringSectionWarns(warns), index
+    return DocstringSectionWarns(warns), new_offset
 
 
 def _read_attributes_section(
@@ -438,24 +521,31 @@ def _read_attributes_section(
     # attributes (for classes)
     # NAME( : TYPE)?
     #    TEXT?
-    items, index = _read_block_items(docstring, offset)
+    items, new_offset = _read_block_items(docstring, offset)
 
     if not items:
-        _warn(docstring, index, f"Empty attributes section at line {offset}")
-        return None, index
+        _warn(docstring, new_offset, f"Empty attributes section at line {offset}")
+        return None, new_offset
 
-    annotation: str | None
+    annotation: str | Name | Expression | None = None
     attributes = []
     for item in items:
         name_type = item[0]
-        if " : " in name_type:
-            name, annotation = name_type.split(" : ", 1)
+        if ":" in name_type:
+            name, annotation = name_type.split(":", 1)
+            name = name.strip()
+            annotation = annotation.strip()
         else:
             name = name_type
-            annotation = None
+        annotation = annotation or None
+        if annotation is None:
+            with suppress(AttributeError, KeyError):
+                annotation = docstring.parent.members[name].annotation  # type: ignore[union-attr]
+        else:
+            annotation = parse_annotation(annotation, docstring)  # type: ignore[arg-type]
         text = dedent("\n".join(item[1:]))
         attributes.append(DocstringAttribute(name=name, annotation=annotation, description=text))
-    return DocstringSectionAttributes(attributes), index
+    return DocstringSectionAttributes(attributes), new_offset
 
 
 def _read_examples_section(  # noqa: WPS231
@@ -464,7 +554,7 @@ def _read_examples_section(  # noqa: WPS231
     trim_doctest_flags: bool = True,
     **options: Any,
 ) -> tuple[DocstringSectionExamples | None, int]:
-    text, index = _read_block(docstring, offset)
+    text, new_offset = _read_block(docstring, offset)
 
     sub_sections: list[tuple[Literal[DocstringSectionKind.text] | Literal[DocstringSectionKind.examples], str]] = []
     in_code_example = False
@@ -514,10 +604,10 @@ def _read_examples_section(  # noqa: WPS231
         sub_sections.append((DocstringSectionKind.examples, "\n".join(current_example)))
 
     if sub_sections:
-        return DocstringSectionExamples(sub_sections), index
+        return DocstringSectionExamples(sub_sections), new_offset
 
-    _warn(docstring, index, f"Empty examples section at line {offset}")
-    return None, index
+    _warn(docstring, new_offset, f"Empty examples section at line {offset}")
+    return None, new_offset
 
 
 _section_reader = {
@@ -536,6 +626,7 @@ _section_reader = {
 
 def parse(  # noqa: WPS231
     docstring: Docstring,
+    ignore_init_summary: bool = False,
     trim_doctest_flags: bool = True,
     **options: Any,
 ) -> list[DocstringSection]:
@@ -546,6 +637,7 @@ def parse(  # noqa: WPS231
 
     Parameters:
         docstring: The docstring to parse.
+        ignore_init_summary: Whether to ignore the summary in `__init__` methods' docstrings.
         trim_doctest_flags: Whether to remove doctest flags from Python example blocks.
         **options: Additional parsing options.
 
@@ -556,41 +648,54 @@ def parse(  # noqa: WPS231
     current_section = []
 
     in_code_block = False
+    lines = docstring.lines
 
     options = {
         "trim_doctest_flags": trim_doctest_flags,
+        "ignore_init_summary": ignore_init_summary,
         **options,
     }
 
-    lines = docstring.lines
-    index = 0
+    ignore_summary = (
+        options["ignore_init_summary"]  # noqa: WPS222
+        and docstring.parent is not None
+        and docstring.parent.name == "__init__"
+        and docstring.parent.is_function
+        and docstring.parent.parent is not None
+        and docstring.parent.parent.is_class
+    )
 
-    while index < len(lines):
-        line_lower = lines[index].lower()
+    if ignore_summary:
+        offset = 2
+    else:
+        offset = 0
+
+    while offset < len(lines):
+        line_lower = lines[offset].lower()
 
         if in_code_block:
             if line_lower.lstrip(" ").startswith("```"):
                 in_code_block = False
-            current_section.append(lines[index])
+            current_section.append(lines[offset])
 
-        elif line_lower in _section_kind and _is_dash_line(lines[index + 1]):
+        elif line_lower in _section_kind and _is_dash_line(lines[offset + 1]):
             if current_section:
                 if any(current_section):
                     sections.append(DocstringSectionText("\n".join(current_section).rstrip("\n")))
                 current_section = []
             reader = _section_reader[_section_kind[line_lower]]
-            section, index = reader(docstring, index + 2, **options)  # type: ignore[operator]
+            section, offset = reader(docstring, offset + 2, **options)  # type: ignore[operator]
             if section:
                 sections.append(section)
 
         elif line_lower.lstrip(" ").startswith("```"):
             in_code_block = True
-            current_section.append(lines[index])
+            current_section.append(lines[offset])
 
         else:
-            current_section.append(lines[index])
+            current_section.append(lines[offset])
 
-        index += 1
+        offset += 1
 
     if current_section:
         sections.append(DocstringSectionText("\n".join(current_section).rstrip("\n")))
