@@ -3,6 +3,7 @@
 from __future__ import annotations
 
 import os
+import re
 import sys
 from contextlib import suppress
 from pathlib import Path
@@ -41,7 +42,7 @@ class Package:
 class ModuleFinder:
     """The Griffe finder, allowing to find modules on the file system."""
 
-    accepted_py_module_extensions = [".py", ".pyc", ".pyo", ".pyd", ".so"]
+    accepted_py_module_extensions = [".py", ".pyc", ".pyo", ".pyd", ".pyi", ".so"]
     extensions_set = set(accepted_py_module_extensions)
 
     def __init__(self, search_paths: Sequence[str | Path] | None = None) -> None:
@@ -139,10 +140,9 @@ class ModuleFinder:
                             return abs_path
                         else:
                             init_module = abs_path / "__init__.py"
-                            if init_module.exists():
+                            if init_module.exists() and not _is_pkg_style_namespace(init_module):
                                 return init_module
-                            else:
-                                namespace_dirs.append(abs_path)
+                            namespace_dirs.append(abs_path)
 
         if namespace_dirs:
             return namespace_dirs
@@ -166,7 +166,7 @@ class ModuleFinder:
 
         if path.stem == "__init__":
             path = path.parent
-        # optimization: just check if the file name ends with .py[cod]/.so
+        # optimization: just check if the file name ends with .py[icod]/.so
         # (to distinguish it from a directory),
         # not if it's an actual file
         elif path.suffix in self.extensions_set:
@@ -269,6 +269,17 @@ class ModuleFinder:
         return parent_path.name
 
 
+_re_pkgresources = re.compile(r"(?:__import__\([\"']pkg_resources[\"']\).declare_namespace\(__name__\))")
+_re_pkgutil = re.compile(r"(?:__path__ = __import__\([\"']pkgutil[\"']\).extend_path\(__path__, __name__\))")
+
+
+# TODO: for better robustness, we should load and minify the AST
+# to search for particular call statements
+def _is_pkg_style_namespace(init_module: Path) -> bool:
+    code = init_module.read_text()
+    return bool(_re_pkgresources.search(code) or _re_pkgutil.search(code))
+
+
 def _module_depth(name_parts_and_path: NamePartsAndPathType) -> int:
     return len(name_parts_and_path[0])
 
